@@ -15,8 +15,9 @@ class PlotCommon(object):
             codepath = os.path.dirname(os.path.realpath(__file__))
             makeIntra = codepath+"/extract/makeMatrixIntra.sh"
             juicer = codepath+"/jc/jctool_1.11.04.jar"
-            os.system("bash "+makeIntra+" "+"KR"+" "+"."+" "+path+" "+str(resolution)+" "+gt+" "+juicer+" "+chr)
-            path = "./MatrixTemp/"+str(resolution)+"/observed.KR."+chr+".matrix.gz"
+            foldername = "./MatrixTemp"+str(random.random())
+            os.system("bash "+makeIntra+" "+"KR"+" "+"."+" "+path+" "+str(resolution)+" "+gt+" "+juicer+" "+chr+" "+foldername+ ">> info.txt")
+            path = foldername+"/"+str(resolution)+"/observed.KR."+chr+".matrix.gz"
         matrix = loadDenseMatrix(path).values
 
         self.path = path
